==> client-3.7.0-sources.jar: com/nexmo/client/sms/SmsIdSearchRequest.java <==
/*
 * Copyright (c) 2011-2017 Nexmo Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.nexmo.client.sms;

import org.apache.http.client.methods.RequestBuilder;

import java.util.ArrayList;
import java.util.List;

public class SmsIdSearchRequest implements SearchSmsRequest {
    private final List<String> ids;

    public SmsIdSearchRequest(String id) {
        this(new ArrayList<String>(10));
        ids.add(id);
    }

    public SmsIdSearchRequest(List<String> ids) {
        this.ids = new ArrayList<>(ids);
    }

    public void addId(String id) {
        this.ids.add(id);
    }

    public void addParams(RequestBuilder request) {
        for (String id : this.ids) {
            request.addParameter("ids", id);
        }

    }
}

==> client-5.6.0-sources.jar: com/nexmo/client/sms/SmsIdSearchRequest.java <==
/*
 * Copyright (c) 2011-2017 Nexmo Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.nexmo.client.sms;

import org.apache.http.client.methods.RequestBuilder;

import java.util.ArrayList;
import java.util.List;

public class SmsIdSearchRequest implements SearchSmsRequest {
    private final List<String> ids;

    public SmsIdSearchRequest(String id) {
        this(new ArrayList<>(10));
        ids.add(id);
    }

    public SmsIdSearchRequest(List<String> ids) {
        this.ids = new ArrayList<>(ids);
    }

    public void addId(String id) {
        this.ids.add(id);
    }

    public void addParams(RequestBuilder request) {
        for (String id : this.ids) {
            request.addParameter("ids", id);
        }

    }
}
